@@ -67,7 +67,7 @@ PyObject *netinfo_adddel_route(PyObject *self, PyObject *args, int action)
     rtentry.rt_genmask.sa_family = AF_INET;
     sin = (struct sockaddr_in *)&rtentry.rt_genmask;
     inet_aton(netmask, &sin->sin_addr);
-    if (sin->sin_addr.s_addr != 0xFFFFFFFF)
+    if (sin->sin_addr.s_addr == 0xFFFFFFFF)
         rtentry.rt_flags |= RTF_HOST;
     /* add route */
     ret = ioctl(fd, action ? SIOCADDRT : SIOCDELRT, &rtentry);
